@@ -154,9 +154,9 @@ class ElasticSearch(object):
 
     def get_indices(self, include_aliases=False):
         """
-        Get a dict holding an entry for each index which exits.
+        Get a dict holding an entry for each index which exists.
 
-        If includeAliases is True, the dict will also contain entries for
+        If ``include_aliases`` is True, the dict will also contain entries for
         aliases.
 
         The key for each entry in the dict is the index or alias name. The
@@ -173,8 +173,9 @@ class ElasticSearch(object):
                 info = indices[index]
                 num_docs = info['docs']['num_docs']
                 result[index] = {'num_docs': num_docs}
-                if not include_aliases:
+                if not include_aliases or 'aliases' not in info:
                     continue
+
                 for alias in info['aliases']:
                     if alias not in result:
                         result[alias] = dict()
@@ -353,12 +354,13 @@ class ElasticSearch(object):
     def get_mapping(self, doc_type=None, indexes=None):
         """Get the mapping definition"""
         indices = self._validate_indexes(indexes)
-        path = [','.join(indices)]
+        path_items = [','.join(indices)]
 
         if doc_type:
-            path.append(doc_type)
+            path_items.append(doc_type)
 
-        path.append('_mapping')
+        path_items.append('_mapping')
+        path = self._make_path(path_items)
         d = self._send_request('GET', path)
         return d
 
@@ -532,7 +534,8 @@ class ElasticSearch(object):
 
         path = self._make_path(
             [','.join(indices), ','.join(doc_types), '_query'])
-        d = self._send_request('DELETE', path, params=params)
+        body = {'query': query}
+        d = self._send_request('DELETE', path, body, params=params)
         return d
 
     def delete_mapping(self, index, doc_type):
@@ -557,7 +560,7 @@ class ElasticSearch(object):
 
         ids can be:
             list of tuples: (index, type, id)
-            list of ids: index and docType are required
+            list of ids: index and doc_type are required
         """
         if not ids:
             return []
@@ -636,18 +639,6 @@ class ElasticSearch(object):
         d.addCallback(scroll)
         return d
 
-    def reindex(self, query, indexes=None, doc_types=None, **params):
-        """Execute a query against one or more indices & reindex hits."""
-        indices = self._validate_indexes(indexes)
-        if not doc_types:
-            doc_types = []
-        elif isinstance(doc_types, basestring):
-            doc_types = [doc_types]
-        path = self._make_path([','.join(indices), ','.join(doc_types),
-                               '_reindexbyquery'])
-        d = self._send_request('POST', path, body=query, params=params)
-        return d
-
     def count(self, query, indexes=None, doc_types=None, **params):
         """Execute a query against one or more indices & get the hit count."""
         indices = self._validate_indexes(indexes)
@@ -669,9 +660,9 @@ class ElasticSearch(object):
         d = self._send_request('DELETE', '/_river/{}/'.format(river_name))
         return d
 
-    def more_like_this(self, index, docType, id, fields, **params):
+    def more_like_this(self, index, doc_type, id, fields, **params):
         """Execute a "more like this" query against one or more fields."""
-        path = self._make_path([index, docType, id, '_mlt'])
+        path = self._make_path([index, doc_type, id, '_mlt'])
         params['fields'] = ','.join(fields)
         d = self._send_request('GET', path, params=params)
         return d
